@@ -1,6 +1,8 @@
+from typing import Any, List, Mapping, Optional, Sequence, Union
+
 import apispec as _apispec
-from typing import Sequence, Any, Optional, Union, List, Dict
-from openapify.core.openapi.models import Server, SecurityScheme
+
+from openapify.core.openapi.models import SecurityScheme, Server
 
 
 class APISpec(_apispec.APISpec):
@@ -11,7 +13,7 @@ class APISpec(_apispec.APISpec):
         openapi_version: str,
         plugins: Sequence[_apispec.BasePlugin] = (),
         servers: Optional[List[Union[str, Server]]] = None,
-        security_schemes: Optional[Dict[str, SecurityScheme]] = None,
+        security_schemes: Optional[Mapping[str, SecurityScheme]] = None,
         **options: Any,
     ) -> None:
         _servers = []
