@@ -5,6 +5,7 @@ from typing import (
     Dict,
     Iterable,
     List,
+    Mapping,
     Optional,
     Sequence,
     Tuple,
@@ -254,7 +255,7 @@ class OpenAPISpecBuilder:
                     allowEmptyValue=param.allowEmptyValue,
                     schema=parameter_schema,
                     example=param.example,
-                    examples=param.examples,
+                    examples=self._build_examples(param.examples),
                 )
             )
         return result
@@ -279,7 +280,7 @@ class OpenAPISpecBuilder:
                     allowEmptyValue=header.allowEmptyValue,
                     schema=parameter_schema,
                     example=header.example,
-                    examples=header.examples,
+                    examples=self._build_examples(header.examples),
                 )
             )
         return result
@@ -304,7 +305,7 @@ class OpenAPISpecBuilder:
                     allowEmptyValue=cookie.allowEmptyValue,
                     schema=parameter_schema,
                     example=cookie.example,
-                    examples=cookie.examples,
+                    examples=self._build_examples(cookie.examples),
                 )
             )
         return result
@@ -330,7 +331,9 @@ class OpenAPISpecBuilder:
             description=description,
             content={
                 media_type: openapi.MediaType(
-                    schema=schema, example=example, examples=examples
+                    schema=schema,
+                    example=example,
+                    examples=self._build_examples(examples),
                 )
             },
             required=required,
@@ -352,10 +355,6 @@ class OpenAPISpecBuilder:
                         self.spec, value, APISpecObjectType.HEADER, key
                     )
                     headers[key] = openapi.Header(header_schema)
-        if examples:
-            for key, value in examples.items():
-                if not isinstance(value, openapi.Example):
-                    examples[key] = openapi.Example(value=value)
         component_id = type_name(schema, short=True)
         component_schema = build_json_schema(schema, self.spec)
         if component_schema:
@@ -369,7 +368,9 @@ class OpenAPISpecBuilder:
             headers=headers,
             content={
                 media_type: openapi.MediaType(
-                    schema=schema, example=example, examples=examples
+                    schema=schema,
+                    example=example,
+                    examples=self._build_examples(examples),
                 ),
             },
         )
@@ -406,6 +407,18 @@ class OpenAPISpecBuilder:
                 result.append({name: []})
         return result
 
+    @staticmethod
+    def _build_examples(
+        examples: Optional[Mapping[str, Union[openapi.Example, Any]]] = None,
+    ) -> Optional[Mapping[str, openapi.Example]]:
+        if examples is None:
+            return None
+        result = {}
+        for key, value in examples.items():
+            if not isinstance(value, openapi.Example):
+                result[key] = openapi.Example(value)
+        return result
+
 
 def build_spec(
     routes: Iterable[RouteDef],
